@@ -166,7 +166,7 @@ test_conv(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
 	if(data1[i] != data2[i]) {
 	    H5_FAILED();
-	    printf("    1. data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
+	    HDprintf("    1. data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
 		   (unsigned long)i, (int)(data1[i]),
 		   (unsigned long)i, (int)(data2[i]));
 	    goto error;
@@ -178,7 +178,7 @@ test_conv(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
 	if((short)data1[i] != data_short[i]) {
 	    H5_FAILED();
-	    printf("    2. data1[%lu]=%d, data_short[%lu]=%d (should be same)\n",
+	    HDprintf("    2. data1[%lu]=%d, data_short[%lu]=%d (should be same)\n",
 		   (unsigned long)i, (int)(data1[i]),
 		   (unsigned long)i, (int)(data_short[i]));
 	    goto error;
@@ -190,7 +190,7 @@ test_conv(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
 	if((int)data1[i] != (int)data_double[i]) {
 	    H5_FAILED();
-	    printf("    3. data1[%lu]=%d, data_double[%lu]=%d (should be same)\n",
+	    HDprintf("    3. data1[%lu]=%d, data_double[%lu]=%d (should be same)\n",
 		   (unsigned long)i, (int)(data1[i]),
 		   (unsigned long)i, (int)(data_double[i]));
 	    goto error;
@@ -212,7 +212,7 @@ test_conv(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
 	if((int)data1[i] != data_int[i]) {
 	    H5_FAILED();
-	    printf("    4. data1[%lu]=%d, data_int[%lu]=%d (should be same)\n",
+	    HDprintf("    4. data1[%lu]=%d, data_int[%lu]=%d (should be same)\n",
 		   (unsigned long)i, (int)(data1[i]),
 		   (unsigned long)i, (int)(data_int[i]));
 	    goto error;
@@ -234,7 +234,7 @@ test_conv(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
 	if((int)data1[i] != (int)data_double[i]) {
 	    H5_FAILED();
-	    printf("    5. data1[%lu]=%d, data_double[%lu]=%d (should be same)\n",
+	    HDprintf("    5. data1[%lu]=%d, data_double[%lu]=%d (should be same)\n",
 		   (unsigned long)i, (int)(data1[i]),
 		   (unsigned long)i, (int)(data_double[i]));
 	    goto error;
@@ -318,7 +318,7 @@ test_tr1(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
         if(data1[i] != data2[i]) {
             H5_FAILED();
-            printf("    data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
+            HDprintf("    data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
                     (unsigned long)i, (int)(data1[i]),
                     (unsigned long)i, (int)(data2[i]));
             goto error;
@@ -400,7 +400,7 @@ test_tr2(hid_t file)
     for(i = 0; i < (size_t)ds_size[0]; i++)
         if(data1[i] != data2[i]) {
             H5_FAILED();
-            printf("    data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
+            HDprintf("    data1[%lu]=%d, data2[%lu]=%d (should be same)\n",
                     (unsigned long)i, (int)(data1[i]),
                     (unsigned long)i, (int)(data2[i]));
             goto error;
@@ -559,7 +559,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (ret>=0) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
@@ -568,7 +568,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (size>0) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
@@ -577,7 +577,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (inpad>-1) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
@@ -586,7 +586,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (cset>-1) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
@@ -596,7 +596,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (ret>=0) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
@@ -605,7 +605,7 @@ test_funcs(void)
     } H5E_END_TRY;
     if (ret>=0) {
         H5_FAILED();
-        printf("Operation not allowed for this type.\n");
+        HDprintf("Operation not allowed for this type.\n");
         goto error;
     } /* end if */
 
