@@ -671,6 +671,14 @@ error:
  *
  ******************************************************************************
  */
+/* Disable warning for "format not a string literal" here -QAK */
+/*
+ *      This pragma only needs to surround the snprintf() calls with
+ *      'member_file_name' in the code below, but early (4.4.7, at least) gcc only
+ *      allows diagnostic pragmas to be toggled outside of functions.
+ */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
 static int
 test_get_file_image(const char * test_banner,
                     const int file_name_num,
@@ -937,6 +945,7 @@ test_get_file_image(const char * test_banner,
 error:
     return 1;
 } /* end test_get_file_image() */
+#pragma GCC diagnostic pop
 
 
 /******************************************************************************
