@@ -163,7 +163,7 @@ void test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Fill the buffer with two copies of the UTF-8 string, each with a
      * terminating NULL.  It will look like "abcdefg\0abcdefg\0". */
-    strncpy(buf, new_string, big_len);
+    HDstrncpy(buf, new_string, big_len);
     HDstrncpy(&buf[big_len], new_string, big_len);
 
     ret = H5Tconvert(src_type, dst_type, (size_t)2, buf, NULL, H5P_DEFAULT);
@@ -774,15 +774,15 @@ void dump_string(const char * string)
   size_t length;
   size_t x;
 
-  printf("The string was:\n %s", string);
-  printf("Or in hex:\n");
+  HDprintf("The string was:\n %s", string);
+  HDprintf("Or in hex:\n");
 
   length = HDstrlen(string);
 
   for(x=0; x<length; x++)
-    printf("%x ", string[x] & (0x000000FF));
+    HDprintf("%x ", string[x] & (0x000000FF));
 
-  printf("\n");
+  HDprintf("\n");
 }
 
 /* Main test.
@@ -854,7 +854,7 @@ void test_unicode(void)
  */
 void cleanup_unicode(void)
 {
-    remove(FILENAME);
+    HDremove(FILENAME);
 }
 
 
