@@ -21,19 +21,19 @@
  *
  *-------------------------------------------------------------------------
  */
-#define H5A_FRIEND		/*suppress error about including H5Apkg  */
-#define H5B2_FRIEND		/*suppress error about including H5B2pkg */
-#define H5B2_TESTING		/*suppress warning about H5B2 testing funcs*/
-#define H5D_FRIEND		/*suppress error about including H5Dpkg  */
-#define H5EA_FRIEND		/*suppress error about including H5EApkg */
-#define H5EA_TESTING		/*suppress warning about H5EA testing funcs*/
-#define H5FA_FRIEND		/*suppress error about including H5FApkg */
-#define H5FA_TESTING		/*suppress warning about H5FA testing funcs*/
-#define H5F_FRIEND		/*suppress error about including H5Fpkg  */
-#define H5G_FRIEND		/*suppress error about including H5Gpkg  */
-#define H5HF_FRIEND		/*suppress error about including H5HFpkg */
-#define H5O_FRIEND		/*suppress error about including H5Opkg  */
-#define H5SM_FRIEND		/*suppress error about including H5SMpkg */
+#define H5A_FRIEND        /*suppress error about including H5Apkg  */
+#define H5B2_FRIEND        /*suppress error about including H5B2pkg */
+#define H5B2_TESTING        /*suppress warning about H5B2 testing funcs*/
+#define H5D_FRIEND        /*suppress error about including H5Dpkg  */
+#define H5EA_FRIEND        /*suppress error about including H5EApkg */
+#define H5EA_TESTING        /*suppress warning about H5EA testing funcs*/
+#define H5FA_FRIEND        /*suppress error about including H5FApkg */
+#define H5FA_TESTING        /*suppress warning about H5FA testing funcs*/
+#define H5F_FRIEND        /*suppress error about including H5Fpkg  */
+#define H5G_FRIEND        /*suppress error about including H5Gpkg  */
+#define H5HF_FRIEND        /*suppress error about including H5HFpkg */
+#define H5O_FRIEND        /*suppress error about including H5Opkg  */
+#define H5SM_FRIEND        /*suppress error about including H5SMpkg */
 
 #include "H5private.h"  /* Generic Functions    */
 #include "H5Apkg.h"     /* Attributes           */
@@ -57,7 +57,7 @@
 
 #define VCOL    50
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    get_H5B2_class
  *
@@ -80,68 +80,68 @@ get_H5B2_class(const uint8_t *sig)
     const H5B2_class_t *cls;
 
     switch(subtype) {
-        case H5B2_TEST_ID:
-            cls = H5B2_TEST;
-            break;
+    case H5B2_TEST_ID:
+        cls = H5B2_TEST;
+        break;
 
-        case H5B2_FHEAP_HUGE_INDIR_ID:
-            cls = H5HF_HUGE_BT2_INDIR;
-            break;
+    case H5B2_FHEAP_HUGE_INDIR_ID:
+        cls = H5HF_HUGE_BT2_INDIR;
+        break;
 
-        case H5B2_FHEAP_HUGE_FILT_INDIR_ID:
-            cls = H5HF_HUGE_BT2_FILT_INDIR;
-            break;
+    case H5B2_FHEAP_HUGE_FILT_INDIR_ID:
+        cls = H5HF_HUGE_BT2_FILT_INDIR;
+        break;
 
-        case H5B2_FHEAP_HUGE_DIR_ID:
-            cls = H5HF_HUGE_BT2_DIR;
-            break;
+    case H5B2_FHEAP_HUGE_DIR_ID:
+        cls = H5HF_HUGE_BT2_DIR;
+        break;
 
-        case H5B2_FHEAP_HUGE_FILT_DIR_ID:
-            cls = H5HF_HUGE_BT2_FILT_DIR;
-            break;
+    case H5B2_FHEAP_HUGE_FILT_DIR_ID:
+        cls = H5HF_HUGE_BT2_FILT_DIR;
+        break;
 
-        case H5B2_GRP_DENSE_NAME_ID:
-            cls = H5G_BT2_NAME;
-            break;
+    case H5B2_GRP_DENSE_NAME_ID:
+        cls = H5G_BT2_NAME;
+        break;
 
-        case H5B2_GRP_DENSE_CORDER_ID:
-            cls = H5G_BT2_CORDER;
-            break;
+    case H5B2_GRP_DENSE_CORDER_ID:
+        cls = H5G_BT2_CORDER;
+        break;
 
-        case H5B2_SOHM_INDEX_ID:
-            cls = H5SM_INDEX;
-            break;
+    case H5B2_SOHM_INDEX_ID:
+        cls = H5SM_INDEX;
+        break;
 
-        case H5B2_ATTR_DENSE_NAME_ID:
-            cls = H5A_BT2_NAME;
-            break;
+    case H5B2_ATTR_DENSE_NAME_ID:
+        cls = H5A_BT2_NAME;
+        break;
 
-        case H5B2_ATTR_DENSE_CORDER_ID:
-            cls = H5A_BT2_CORDER;
-            break;
+    case H5B2_ATTR_DENSE_CORDER_ID:
+        cls = H5A_BT2_CORDER;
+        break;
 
-        case H5B2_CDSET_ID:
-            cls = H5D_BT2;
-            break;
+    case H5B2_CDSET_ID:
+        cls = H5D_BT2;
+        break;
 
-        case H5B2_CDSET_FILT_ID:
-            cls = H5D_BT2_FILT;
-            break;
+    case H5B2_CDSET_FILT_ID:
+        cls = H5D_BT2_FILT;
+        break;
 
-        case H5B2_TEST2_ID:
-            cls = H5B2_TEST2;
-            break;
+    case H5B2_TEST2_ID:
+        cls = H5B2_TEST2;
+        break;
 
-        case H5B2_NUM_BTREE_ID:
-        default:
-            HDfprintf(stderr, "Unknown v2 B-tree subtype %u\n", (unsigned)(subtype));
-            HDexit(4);
+    case H5B2_NUM_BTREE_ID:
+    default:
+        HDfprintf(stderr, "Unknown v2 B-tree subtype %u\n", (unsigned)(subtype));
+        HDexit(4);
     } /* end switch */
 
     return(cls);
 } /* end get_H5B2_class() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    get_H5EA_class
  *
@@ -164,28 +164,28 @@ get_H5EA_class(const uint8_t *sig)
     const H5EA_class_t *cls;
 
     switch(clsid) {
-        case H5EA_CLS_TEST_ID:
-            cls = H5EA_CLS_TEST;
-            break;
+    case H5EA_CLS_TEST_ID:
+        cls = H5EA_CLS_TEST;
+        break;
 
-        case H5EA_CLS_CHUNK_ID:
-            cls = H5EA_CLS_CHUNK;
-            break;
+    case H5EA_CLS_CHUNK_ID:
+        cls = H5EA_CLS_CHUNK;
+        break;
 
-        case H5EA_CLS_FILT_CHUNK_ID:
-            cls = H5EA_CLS_FILT_CHUNK;
-            break;
+    case H5EA_CLS_FILT_CHUNK_ID:
+        cls = H5EA_CLS_FILT_CHUNK;
+        break;
 
-        case H5EA_NUM_CLS_ID:
-        default:
-            HDfprintf(stderr, "Unknown extensible array class %u\n", (unsigned)(clsid));
-            HDexit(4);
+    case H5EA_NUM_CLS_ID:
+    default:
+        HDfprintf(stderr, "Unknown extensible array class %u\n", (unsigned)(clsid));
+        HDexit(4);
     } /* end switch */
 
     return(cls);
 } /* end get_H5EA_class() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    get_H5FA_class
  *
@@ -208,28 +208,28 @@ get_H5FA_class(const uint8_t *sig)
     const H5FA_class_t *cls;
 
     switch(clsid) {
-        case H5FA_CLS_TEST_ID:
-            cls = H5FA_CLS_TEST;
-            break;
+    case H5FA_CLS_TEST_ID:
+        cls = H5FA_CLS_TEST;
+        break;
 
-        case H5FA_CLS_CHUNK_ID:
-            cls = H5FA_CLS_CHUNK;
-            break;
+    case H5FA_CLS_CHUNK_ID:
+        cls = H5FA_CLS_CHUNK;
+        break;
 
-        case H5FA_CLS_FILT_CHUNK_ID:
-            cls = H5FA_CLS_FILT_CHUNK;
-            break;
+    case H5FA_CLS_FILT_CHUNK_ID:
+        cls = H5FA_CLS_FILT_CHUNK;
+        break;
 
-        case H5FA_NUM_CLS_ID: 
-        default:
-            HDfprintf(stderr, "Unknown fixed array class %u\n", (unsigned)(clsid));
-            HDexit(4);
+    case H5FA_NUM_CLS_ID:
+    default:
+        HDfprintf(stderr, "Unknown fixed array class %u\n", (unsigned)(clsid));
+        HDexit(4);
     } /* end switch */
 
     return(cls);
 } /* end get_H5FA_class() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    main
  *
@@ -254,13 +254,13 @@ main(int argc, char *argv[])
     uint8_t     sig[H5F_SIGNATURE_LEN];
     size_t      u;
     H5E_auto2_t func;
-    void 	*edata;
+    void       *edata;
     hbool_t     api_ctx_pushed = FALSE;             /* Whether API context pushed */
     herr_t      status = SUCCEED;
 
     if(argc == 1) {
-  	HDfprintf(stderr, "Usage: %s filename [signature-addr [extra]]\n", argv[0]);
-  	HDexit(1);
+        HDfprintf(stderr, "Usage: %s filename [signature-addr [extra]]\n", argv[0]);
+        HDexit(1);
     } /* end if */
 
     /* Initialize the library */
@@ -282,7 +282,7 @@ main(int argc, char *argv[])
     } /* end if */
     if(HDstrchr(argv[1], '%'))
         if(H5Pset_fapl_family (fapl, (hsize_t)0, H5P_DEFAULT) < 0) {
-            fprintf(stderr, "cannot set file access property list\n");
+            HDfprintf(stderr, "cannot set file access property list\n");
             HDexit(1);
         }
     if((fid = H5Fopen(argv[1], H5F_ACC_RDONLY, fapl)) < 0) {
@@ -342,13 +342,15 @@ main(int argc, char *argv[])
          */
         status = H5HL_debug(f, addr, stdout, 0, VCOL);
 
-    } else if(!HDmemcmp (sig, H5HG_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
-	/*
-	 * Debug a global heap collection.
-	 */
-	status = H5HG_debug(f, addr, stdout, 0, VCOL);
+    }
+    else if(!HDmemcmp (sig, H5HG_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+        /*
+         * Debug a global heap collection.
+         */
+        status = H5HG_debug(f, addr, stdout, 0, VCOL);
 
-    } else if(!HDmemcmp(sig, H5G_NODE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5G_NODE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a symbol table node.
          */
@@ -362,7 +364,8 @@ main(int argc, char *argv[])
 
         status = H5G_node_debug(f, addr, stdout, 0, VCOL, extra);
 
-    } else if(!HDmemcmp(sig, H5B_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5B_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a B-tree.  B-trees are debugged through the B-tree
          * subclass.  The subclass identifier is the byte immediately
@@ -373,79 +376,81 @@ main(int argc, char *argv[])
         uint32_t    dim[H5O_LAYOUT_NDIMS];
 
         switch(subtype) {
-            case H5B_SNODE_ID:
-                /* Check for extra parameters */
-                if(extra == 0) {
-                    HDfprintf(stderr, "\nWarning: Providing the group's local heap address will give more information\n");
-                    HDfprintf(stderr, "B-tree symbol table node usage:\n");
-                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <address of local heap>\n\n");
-                    HDexit(4);
-                } /* end if */
-
-                status = H5G_node_debug(f, addr, stdout, 0, VCOL, extra);
-                break;
-
-            case H5B_CHUNK_ID:
-                /* Check for extra parameters */
-                if(extra == 0) {
-                    HDfprintf(stderr, "ERROR: Need number of dimensions of chunk in order to dump chunk B-tree node\n");
-                    HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
-                    HDexit(4);
-                } /* end if */
-
-                /* Build array of chunk dimensions */
-                ndims = (unsigned)extra;
-                dim[0] = (uint32_t)extra2;
-                if(ndims > 1)
-                    dim[1] = (uint32_t)extra3;
-                if(ndims > 2)
-                    dim[2] = (uint32_t)extra4;
-
-                /* Check for dimension error */
-                if(ndims > 3) {
-                    HDfprintf(stderr, "ERROR: Only 3 dimensions support currently (fix h5debug)\n");
-                    HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
-                    HDexit(4);
-                } /* end for */
-                for(u = 0; u < ndims; u++)
-                    if(0 == dim[u]) {
-                        HDfprintf(stderr, "ERROR: Chunk dimensions should be >0\n");
-                        HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                        HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
-                        HDexit(4);
-                    } /* end if */
-
-                /* Set the last dimension (the element size) to zero */
-                dim[ndims] = 0;
-
-                status = H5D_btree_debug(f, addr, stdout, 0, VCOL, ndims, dim);
-                break;
-
-            case H5B_NUM_BTREE_ID:
-            default:
-                HDfprintf(stderr, "Unknown v1 B-tree subtype %u\n", (unsigned)(subtype));
+        case H5B_SNODE_ID:
+            /* Check for extra parameters */
+            if(extra == 0) {
+                HDfprintf(stderr, "\nWarning: Providing the group's local heap address will give more information\n");
+                HDfprintf(stderr, "B-tree symbol table node usage:\n");
+                HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <address of local heap>\n\n");
                 HDexit(4);
+            } /* end if */
+
+            status = H5G_node_debug(f, addr, stdout, 0, VCOL, extra);
+            break;
+
+        case H5B_CHUNK_ID:
+            /* Check for extra parameters */
+            if(extra == 0) {
+                HDfprintf(stderr, "ERROR: Need number of dimensions of chunk in order to dump chunk B-tree node\n");
+                HDfprintf(stderr, "B-tree chunked storage node usage:\n");
+                HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
+                HDexit(4);
+            } /* end if */
+
+            /* Build array of chunk dimensions */
+            ndims = (unsigned)extra;
+            dim[0] = (uint32_t)extra2;
+            if(ndims > 1)
+                dim[1] = (uint32_t)extra3;
+            if(ndims > 2)
+                dim[2] = (uint32_t)extra4;
+
+            /* Check for dimension error */
+            if(ndims > 3) {
+                HDfprintf(stderr, "ERROR: Only 3 dimensions support currently (fix h5debug)\n");
+                HDfprintf(stderr, "B-tree chunked storage node usage:\n");
+                HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
+                HDexit(4);
+            } /* end for */
+            for(u = 0; u < ndims; u++)
+                if(0 == dim[u]) {
+                    HDfprintf(stderr, "ERROR: Chunk dimensions should be >0\n");
+                    HDfprintf(stderr, "B-tree chunked storage node usage:\n");
+                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest chunk dim>...<fastest chunk dim>\n");
+                    HDexit(4);
+                } /* end if */
+
+            /* Set the last dimension (the element size) to zero */
+            dim[ndims] = 0;
+
+            status = H5D_btree_debug(f, addr, stdout, 0, VCOL, ndims, dim);
+            break;
+
+        case H5B_NUM_BTREE_ID:
+        default:
+            HDfprintf(stderr, "Unknown v1 B-tree subtype %u\n", (unsigned)(subtype));
+            HDexit(4);
         }
 
-    } else if(!HDmemcmp(sig, H5B2_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5B2_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree header.
-         */
+          */
         const H5B2_class_t *cls = get_H5B2_class(sig);
         HDassert(cls);
 
-	    if((cls == H5D_BT2 || cls == H5D_BT2_FILT) && extra == 0) {
+        if((cls == H5D_BT2 || cls == H5D_BT2_FILT) && extra == 0) {
             HDfprintf(stderr, "ERROR: Need v2 B-tree header address and object header address containing the layout message in order to dump header\n");
             HDfprintf(stderr, "v2 B-tree hdr usage:\n");
             HDfprintf(stderr, "\th5debug <filename> <v2 B-tree header address> <object header address>\n");
             HDexit(4);
-	    } /* end if */
+        } /* end if */
 
         status = H5B2__hdr_debug(f, addr, stdout, 0, VCOL, cls, (haddr_t)extra);
 
-    } else if(!HDmemcmp(sig, H5B2_INT_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5B2_INT_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree internal node.
          */
@@ -453,16 +458,15 @@ main(int argc, char *argv[])
         HDassert(cls);
 
         /* Check for enough valid parameters */
-	if((cls == H5D_BT2 || cls == H5D_BT2_FILT) &&
-	   (extra == 0 || extra2 == 0 || extra3 == 0 || extra4 == 0)) {
-
-            fprintf(stderr, "ERROR: Need v2 B-tree header address, the node's number of records, depth, and object header address containing the layout message in order to dump internal node\n");
-            fprintf(stderr, "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
-            fprintf(stderr, "v2 B-tree internal node usage:\n");
-            fprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> <number of records> <depth> <object header address>\n");
+        if((cls == H5D_BT2 || cls == H5D_BT2_FILT) && (extra == 0 || extra2 == 0 || extra3 == 0 || extra4 == 0)) {
+            HDfprintf(stderr, "ERROR: Need v2 B-tree header address, the node's number of records, depth, and object header address containing the layout message in order to dump internal node\n");
+            HDfprintf(stderr, "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
+            HDfprintf(stderr, "v2 B-tree internal node usage:\n");
+            HDfprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> <number of records> <depth> <object header address>\n");
             HDexit(4);
 
-        } else if(extra == 0 || extra2 == 0 || extra3 == 0) {
+        }
+        else if(extra == 0 || extra2 == 0 || extra3 == 0) {
             HDfprintf(stderr, "ERROR: Need v2 B-tree header address and the node's number of records and depth in order to dump internal node\n");
             HDfprintf(stderr, "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
             HDfprintf(stderr, "v2 B-tree internal node usage:\n");
@@ -472,7 +476,8 @@ main(int argc, char *argv[])
 
         status = H5B2__int_debug(f, addr, stdout, 0, VCOL, cls, extra, (unsigned)extra2, (unsigned)extra3, (haddr_t)extra4);
 
-    } else if(!HDmemcmp(sig, H5B2_LEAF_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5B2_LEAF_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree leaf node.
          */
@@ -480,15 +485,15 @@ main(int argc, char *argv[])
         HDassert(cls);
 
         /* Check for enough valid parameters */
-	if((cls == H5D_BT2 || cls == H5D_BT2_FILT) &&
-	   (extra == 0 || extra2 == 0 || extra3 == 0 )) {
+        if((cls == H5D_BT2 || cls == H5D_BT2_FILT) && (extra == 0 || extra2 == 0 || extra3 == 0 )) {
 
-            fprintf(stderr, "ERROR: Need v2 B-tree header address, number of records, and object header address containing the layout message in order to dump leaf node\n");
-            fprintf(stderr, "v2 B-tree leaf node usage:\n");
-            fprintf(stderr, "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number of records> <object header address>\n");
+            HDfprintf(stderr, "ERROR: Need v2 B-tree header address, number of records, and object header address containing the layout message in order to dump leaf node\n");
+            HDfprintf(stderr, "v2 B-tree leaf node usage:\n");
+            HDfprintf(stderr, "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number of records> <object header address>\n");
             HDexit(4);
 
-        } else if(extra == 0 || extra2 == 0) {
+        }
+        else if(extra == 0 || extra2 == 0) {
             HDfprintf(stderr, "ERROR: Need v2 B-tree header address and number of records in order to dump leaf node\n");
             HDfprintf(stderr, "v2 B-tree leaf node usage:\n");
             HDfprintf(stderr, "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number of records>\n");
@@ -497,13 +502,15 @@ main(int argc, char *argv[])
 
         status = H5B2__leaf_debug(f, addr, stdout, 0, VCOL, cls, extra, (unsigned)extra2, (haddr_t)extra3);
 
-    } else if(!HDmemcmp(sig, H5HF_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5HF_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap header.
          */
         status = H5HF_hdr_debug(f, addr, stdout, 0, VCOL);
 
-    } else if(!HDmemcmp(sig, H5HF_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5HF_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap direct block.
          */
@@ -518,7 +525,8 @@ main(int argc, char *argv[])
 
         status = H5HF_dblock_debug(f, addr, stdout, 0, VCOL, extra, (size_t)extra2);
 
-    } else if(!HDmemcmp(sig, H5HF_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5HF_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap indirect block.
          */
@@ -533,14 +541,16 @@ main(int argc, char *argv[])
 
         status = H5HF_iblock_debug(f, addr, stdout, 0, VCOL, extra, (unsigned)extra2);
 
-    } else if(!HDmemcmp(sig, H5FS_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5FS_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a free space header.
          */
 
         status = H5FS_debug(f, addr, stdout, 0, VCOL);
 
-    } else if(!HDmemcmp(sig, H5FS_SINFO_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5FS_SINFO_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug free space serialized sections.
          */
@@ -555,14 +565,16 @@ main(int argc, char *argv[])
 
         status = H5FS_sects_debug(f, addr, stdout, 0, VCOL, extra, extra2);
 
-    } else if(!HDmemcmp(sig, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug shared message master table.
          */
 
         status = H5SM_table_debug(f, addr, stdout, 0, VCOL, (unsigned) UFAIL, (unsigned) UFAIL);
 
-    } else if(!HDmemcmp(sig, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug shared message list index.
          */
@@ -577,7 +589,8 @@ main(int argc, char *argv[])
 
         status = H5SM_list_debug(f, addr, stdout, 0, VCOL, (haddr_t)extra);
 
-    } else if(!HDmemcmp(sig, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible aray header.
          */
@@ -594,7 +607,8 @@ main(int argc, char *argv[])
 
         status = H5EA__hdr_debug(f, addr, stdout, 0, VCOL, cls, extra);
 
-    } else if(!HDmemcmp(sig, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible aray index block.
          */
@@ -611,7 +625,8 @@ main(int argc, char *argv[])
 
         status = H5EA__iblock_debug(f, addr, stdout, 0, VCOL, cls, extra, extra2);
 
-    } else if(!HDmemcmp(sig, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible aray super block.
          */
@@ -628,7 +643,8 @@ main(int argc, char *argv[])
 
         status = H5EA__sblock_debug(f, addr, stdout, 0, VCOL, cls, extra, (unsigned)extra2, extra3);
 
-    } else if(!HDmemcmp(sig, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible aray data block.
          */
@@ -645,7 +661,8 @@ main(int argc, char *argv[])
 
         status = H5EA__dblock_debug(f, addr, stdout, 0, VCOL, cls, extra, (size_t)extra2, extra3);
 
-    } else if(!HDmemcmp(sig, H5FA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5FA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fixed array header.
          */
@@ -662,7 +679,8 @@ main(int argc, char *argv[])
 
         status = H5FA__hdr_debug(f, addr, stdout, 0, VCOL, cls, extra);
 
-    } else if(!HDmemcmp(sig, H5FA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5FA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fixed array data block.
          */
@@ -679,33 +697,37 @@ main(int argc, char *argv[])
 
         status = H5FA__dblock_debug(f, addr, stdout, 0, VCOL, cls, extra, extra2);
 
-    } else if(!HDmemcmp(sig, H5O_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    }
+    else if(!HDmemcmp(sig, H5O_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug v2 object header (which have signatures).
          */
 
         status = H5O_debug(f, addr, stdout, 0, VCOL);
 
-    } else if(sig[0] == H5O_VERSION_1) {
+    }
+    else if(sig[0] == H5O_VERSION_1) {
         /*
          * This could be a v1 object header.  Since they don't have a signature
          * it's a somewhat "ify" detection.
          */
         status = H5O_debug(f, addr, stdout, 0, VCOL);
 
-    } else {
+    }
+    else {
         /*
          * Got some other unrecognized signature.
          */
-        printf("%-*s ", VCOL, "Signature:");
+        HDprintf("%-*s ", VCOL, "Signature:");
         for (u = 0; u < sizeof(sig); u++) {
             if (sig[u] > ' ' && sig[u] <= '~' && '\\' != sig[u])
                 HDputchar(sig[u]);
             else if ('\\' == sig[u]) {
                 HDputchar('\\');
                 HDputchar('\\');
-            } else
-                printf("\\%03o", sig[u]);
+            }
+            else
+                HDprintf("\\%03o", sig[u]);
         }
         HDputchar('\n');
 
