@@ -14,7 +14,7 @@
 /*
  * Generate the binary hdf5 files for the h5format_convert tests.
  * Usage: just execute the program without any arguments will
- * generate all the binary hdf5 files 
+ * generate all the binary hdf5 files
  *
  * If you regenerate the test files (e.g., changing some code,
  * trying it on a new platform, ...), you need to verify the correctness
@@ -24,71 +24,71 @@
 #include "hdf5.h"
 #include "H5private.h"
 
-#define NON_V3_FILE		"h5fc_non_v3.h5"
-#define EDGE_V3_FILE		"h5fc_edge_v3.h5"
-#define ERR_LEVEL_FILE		"h5fc_err_level.h5"
+#define NON_V3_FILE        "h5fc_non_v3.h5"
+#define EDGE_V3_FILE        "h5fc_edge_v3.h5"
+#define ERR_LEVEL_FILE        "h5fc_err_level.h5"
 
 const char *FILENAME[] = {
-    "h5fc_ext1_i.h5",	/* 0 */
-    "h5fc_ext1_s.h5",	/* 1 */
-    "h5fc_ext1_f.h5",	/* 2 */
-    "h5fc_ext2_is.h5", 	/* 3 */
-    "h5fc_ext2_if.h5",	/* 4 */
-    "h5fc_ext2_sf.h5", 	/* 5 */
-    "h5fc_ext3_isf.h5",	/* 6 */ 
-    "h5fc_ext_none.h5",	/* 7 */ 
+    "h5fc_ext1_i.h5",    /* 0 */
+    "h5fc_ext1_s.h5",    /* 1 */
+    "h5fc_ext1_f.h5",    /* 2 */
+    "h5fc_ext2_is.h5",     /* 3 */
+    "h5fc_ext2_if.h5",    /* 4 */
+    "h5fc_ext2_sf.h5",     /* 5 */
+    "h5fc_ext3_isf.h5",    /* 6 */
+    "h5fc_ext_none.h5",    /* 7 */
     NULL
 };
 
-#define GROUP			"GROUP"
+#define GROUP            "GROUP"
 
-#define DSET_COMPACT		"DSET_COMPACT"
-#define DSET_CONTIGUOUS		"DSET_CONTIGUOUS"
+#define DSET_COMPACT        "DSET_COMPACT"
+#define DSET_CONTIGUOUS        "DSET_CONTIGUOUS"
 
-#define DSET_EA			"DSET_EA"
-#define DSET_NDATA_EA		"DSET_NDATA_EA"
-#define DSET_BT2		"DSET_BT2"
-#define DSET_NDATA_BT2		"DSET_NDATA_BT2"
-#define DSET_FA			"DSET_FA"
-#define DSET_NDATA_FA		"DSET_NDATA_FA"
-#define DSET_NONE		"DSET_NONE"
-#define DSET_NDATA_NONE		"DSET_NDATA_NONE"
+#define DSET_EA            "DSET_EA"
+#define DSET_NDATA_EA        "DSET_NDATA_EA"
+#define DSET_BT2        "DSET_BT2"
+#define DSET_NDATA_BT2        "DSET_NDATA_BT2"
+#define DSET_FA            "DSET_FA"
+#define DSET_NDATA_FA        "DSET_NDATA_FA"
+#define DSET_NONE        "DSET_NONE"
+#define DSET_NDATA_NONE        "DSET_NDATA_NONE"
 
-#define DSET_EDGE		"DSET_EDGE"
-#define DSET_ERR		"DSET_ERR"
+#define DSET_EDGE        "DSET_EDGE"
+#define DSET_ERR        "DSET_ERR"
 
 #define ISTORE_IK  64
-#define ISTORE_ERR 1 
+#define ISTORE_ERR 1
 
 #define NUM 500
 
 
 /*
- * Function: gen_non() 
+ * Function: gen_non()
  *
  * Create a file with SWMR write+non-latest-format--this will result in v3 superbock+latest version support:
- *	1) 1 chunked dataset with extensible array chunk indexing type (without data)
- *	2) 1 chunked dataset with version 2 B-tree chunk indexing type (with data)
+ *    1) 1 chunked dataset with extensible array chunk indexing type (without data)
+ *    2) 1 chunked dataset with version 2 B-tree chunk indexing type (with data)
  * Re-open the file with write+non-latest-format and create:
- *	3) 1 chunked dataset with version 2 B-tree chunk indexing type (without data)
- * 	4) 1 chunked dataset with extensible array indexing type (with data)
- *	5) 1 compact and 1 contiguous datasets
+ *    3) 1 chunked dataset with version 2 B-tree chunk indexing type (without data)
+ *     4) 1 chunked dataset with extensible array indexing type (with data)
+ *    5) 1 compact and 1 contiguous datasets
  */
 static void
 gen_non(const char *fname)
 {
-    hid_t	fid = -1;		/* file id */
-    hid_t	fcpl = -1;		/* file creation property list */
-    hid_t	gid = -1;		/* group id */
-    hid_t   	sid = -1;       	/* space id */
-    hid_t	dcpl = -1;		/* dataset creation property id */
-    hid_t	did1 = -1, did2 = -1;	/* dataset id */
-    hsize_t 	dims1[1] = {10};     	/* dataset dimension */
-    hsize_t 	dims2[2] = {4, 6};     	/* dataset dimension */
-    hsize_t	max_dims[2];		/* maximum dataset dimension */
-    hsize_t 	c_dims[2] = {2, 3};    	/* chunk dimension */
-    int		i;		    	/* local index variable */
-    int     	buf[24];            	/* data buffer */
+    hid_t    fid = -1;        /* file id */
+    hid_t    fcpl = -1;        /* file creation property list */
+    hid_t    gid = -1;        /* group id */
+    hid_t       sid = -1;           /* space id */
+    hid_t    dcpl = -1;        /* dataset creation property id */
+    hid_t    did1 = -1, did2 = -1;    /* dataset id */
+    hsize_t     dims1[1] = {10};         /* dataset dimension */
+    hsize_t     dims2[2] = {4, 6};         /* dataset dimension */
+    hsize_t    max_dims[2];        /* maximum dataset dimension */
+    hsize_t     c_dims[2] = {2, 3};        /* chunk dimension */
+    int        i;                /* local index variable */
+    int         buf[24];                /* data buffer */
 
     if((fcpl = H5Pcreate(H5P_FILE_CREATE)) < 0)
         goto error;
@@ -115,7 +115,7 @@ gen_non(const char *fname)
     if(H5Pset_chunk(dcpl, 2, c_dims) < 0)
         goto error;
 
-    /* 
+    /*
      * Create a chunked dataset with extensible array chunk indexing type (without data)
      */
 
@@ -135,7 +135,7 @@ gen_non(const char *fname)
     if(H5Dclose(did1) < 0)
         goto error;
 
-    /* 
+    /*
      * Create a chunked dataset with version 2 B-tree chunk indexing type (with data)
      */
 
@@ -226,7 +226,7 @@ gen_non(const char *fname)
     if(H5Dclose(did2) < 0)
         goto error;
 
-    /* 
+    /*
      * Create a compact dataset in the group
      */
 
@@ -251,7 +251,7 @@ gen_non(const char *fname)
     if(H5Sclose(sid) < 0)
         goto error;
 
-    /* 
+    /*
      * Create a contiguous dataset with (2d with data) in the file
      */
     if((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
@@ -278,9 +278,9 @@ gen_non(const char *fname)
         goto error;
 
     if(H5Gclose(gid) < 0)
-	goto error;
+    goto error;
     if(H5Pclose(fcpl) < 0)
-	goto error;
+    goto error;
     if(H5Fclose(fid) < 0)
         goto error;
 
@@ -298,24 +298,24 @@ error:
 } /* gen_non() */
 
 /*
- * Function: gen_edge() 
+ * Function: gen_edge()
  *
  * Create a file with write+latest-format--this will result in v3 superblock+latest version support:
- *	A dataset: chunked, filtered, H5D_CHUNK_DONT_FILTER_PARTIAL_CHUNKS enabled
- *	(i.e. the dataset does not filter partial edge chunks)
+ *    A dataset: chunked, filtered, H5D_CHUNK_DONT_FILTER_PARTIAL_CHUNKS enabled
+ *    (i.e. the dataset does not filter partial edge chunks)
  */
 static void
 gen_edge(const char *fname)
 {
-    hid_t	fid = -1;	    	/* file id */
-    hid_t	fapl = -1;	       	/* file access property list */
-    hid_t   	sid = -1;       	/* dataspace id */
-    hid_t	dcpl = -1;	    	/* dataset creation property id */
-    hid_t	did = -1;		/* dataset id */
-    hsize_t 	dims2[2] = {12, 6};	/* Dataset dimensions */
-    hsize_t 	c_dims[2] = {5, 5};	/* Chunk dimensions */
-    float 	buf[12][6];            	/* Buffer for writing data */
-    int		i, j;		    	/* local index variable */
+    hid_t    fid = -1;            /* file id */
+    hid_t    fapl = -1;               /* file access property list */
+    hid_t       sid = -1;           /* dataspace id */
+    hid_t    dcpl = -1;            /* dataset creation property id */
+    hid_t    did = -1;        /* dataset id */
+    hsize_t     dims2[2] = {12, 6};    /* Dataset dimensions */
+    hsize_t     c_dims[2] = {5, 5};    /* Chunk dimensions */
+    float     buf[12][6];                /* Buffer for writing data */
+    int        i, j;                /* local index variable */
 
     /* Create a new format file */
     if((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
@@ -377,37 +377,37 @@ error:
 
 
 /*
- * Function: gen_err_level() 
+ * Function: gen_err_level()
  *
  * Generate a file to test the situtation described in HDFFV-9434:
- *	Exceed the limit of v1-btree level
+ *    Exceed the limit of v1-btree level
  *
- *	Create a file with H5Pset_istore_k(fcpl, 1).
- *	Create a chunked dataset with extensible array chunk index and 
- *	appends many chunks to the dataset.
+ *    Create a file with H5Pset_istore_k(fcpl, 1).
+ *    Create a chunked dataset with extensible array chunk index and
+ *    appends many chunks to the dataset.
  *
- *	When h5format_convert tries to convert the dataset with
- *	extensive array index in the file to v1-btree chunk index, 
- *	it will insert the dataset chunks to the v1-btree chunk index.
- *	The tree will split quickly due to the 'K' value of 1 and the 
- *	tree level will eventually hit the maximum: 2^8(256).
+ *    When h5format_convert tries to convert the dataset with
+ *    extensive array index in the file to v1-btree chunk index,
+ *    it will insert the dataset chunks to the v1-btree chunk index.
+ *    The tree will split quickly due to the 'K' value of 1 and the
+ *    tree level will eventually hit the maximum: 2^8(256).
  */
 static void
 gen_err_level(const char *fname)
 {
-    hid_t fid = -1;	    	/* file ID */
-    hid_t fapl = -1;	       	/* file access property list */
-    hid_t fcpl = -1;	       	/* file creation property list */
-    hid_t sid = -1;       	/* dataspace id */
-    hid_t dcpl = -1;		/* dataset creation property list */
-    hid_t did = -1;		/* dataset ID */
-    hid_t fsid = -1;		/* file dataspace ID */
-    hid_t msid = -1;		/* memory dataspace ID */
-    unsigned char *buf = NULL;	/* buffer for data */
-    hsize_t dims[2] = {0, 1};			/* dataset dimension sizes */
-    hsize_t max_dims[2] = {1, H5S_UNLIMITED};	/* dataset maximum dimension sizes */
-    hsize_t chunk_dims[2] = {1, 1};		/* chunk dimension sizes */
-    int	n = 0;			/* local index variable */
+    hid_t fid = -1;            /* file ID */
+    hid_t fapl = -1;               /* file access property list */
+    hid_t fcpl = -1;               /* file creation property list */
+    hid_t sid = -1;           /* dataspace id */
+    hid_t dcpl = -1;        /* dataset creation property list */
+    hid_t did = -1;        /* dataset ID */
+    hid_t fsid = -1;        /* file dataspace ID */
+    hid_t msid = -1;        /* memory dataspace ID */
+    unsigned char *buf = NULL;    /* buffer for data */
+    hsize_t dims[2] = {0, 1};            /* dataset dimension sizes */
+    hsize_t max_dims[2] = {1, H5S_UNLIMITED};    /* dataset maximum dimension sizes */
+    hsize_t chunk_dims[2] = {1, 1};        /* chunk dimension sizes */
+    int    n = 0;            /* local index variable */
 
     /* Create a new format file */
     if((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
@@ -440,6 +440,8 @@ gen_err_level(const char *fname)
         goto error;
 
     /* Closing */
+    if(H5Pclose(fcpl) < 0)
+        goto error;
     if(H5Pclose(dcpl) < 0)
         goto error;
     if(H5Sclose(sid) < 0)
@@ -459,50 +461,51 @@ gen_err_level(const char *fname)
 
     /* Loop through appending 1 element at a time */
     for(n = 0; n < NUM; n++) {
-	hsize_t start[2] = {0, 0};
-	hsize_t count[2] = {1, 1};
-	hsize_t extent[2] = {0, 0};
+    hsize_t start[2] = {0, 0};
+    hsize_t count[2] = {1, 1};
+    hsize_t extent[2] = {0, 0};
 
-	start[0] = 0;
-	start[1] = (hsize_t)n;
-	extent[0] = 1;
-	extent[1] = (hsize_t)(n + 1);
+    start[0] = 0;
+    start[1] = (hsize_t)n;
+    extent[0] = 1;
+    extent[1] = (hsize_t)(n + 1);
 
-	/* Set current dimension sizes for the dataset */
-	if(H5Dset_extent(did, extent) < 0)
-	    goto error;
+    /* Set current dimension sizes for the dataset */
+    if(H5Dset_extent(did, extent) < 0)
+        goto error;
 
-	/* Set up memory dataspace */
-	if((msid = H5Screate_simple(2, count, NULL)) < 0)
-	    goto error;
+    /* Set up memory dataspace */
+    if((msid = H5Screate_simple(2, count, NULL)) < 0)
+        goto error;
 
-	/* Get file dataspace */
-	if((fsid = H5Dget_space(did)) < 0)
-	    goto error;
+    /* Get file dataspace */
+    if((fsid = H5Dget_space(did)) < 0)
+        goto error;
 
-	if((H5Sselect_hyperslab(fsid, H5S_SELECT_SET, start, NULL, count, NULL)) < 0)
-	    goto error;
+    if((H5Sselect_hyperslab(fsid, H5S_SELECT_SET, start, NULL, count, NULL)) < 0)
+        goto error;
 
-	/* Write to the dataset */
-	if(H5Dwrite(did, H5T_NATIVE_UCHAR, msid, fsid, H5P_DEFAULT, buf) < 0)
-	    goto error;
+    /* Write to the dataset */
+    if(H5Dwrite(did, H5T_NATIVE_UCHAR, msid, fsid, H5P_DEFAULT, buf) < 0)
+        goto error;
 
-	if(H5Sclose(fsid) < 0)
-	    goto error;
-	if(H5Sclose(msid) < 0)
-	    goto error;
+    if(H5Sclose(fsid) < 0)
+        goto error;
+    if(H5Sclose(msid) < 0)
+        goto error;
     }
 
     /* Closing */
     if(H5Dclose(did) < 0)
-	goto error;
+    goto error;
     if(H5Fclose(fid) < 0)
-	goto error;
+    goto error;
     if(H5Pclose(fapl) < 0)
-	goto error;
-    if(buf) free(buf);
+    goto error;
 
 error:
+    if(buf)
+        free(buf);
     H5E_BEGIN_TRY {
         H5Pclose(dcpl);
         H5Sclose(sid);
@@ -517,33 +520,33 @@ error:
 } /* gen_err_level() */
 
 /*
- * Function: gen_ext() 
+ * Function: gen_ext()
  *
  * Create a file with/without latest format with:
- *	1) 1 contiguous dataset (without data)
- *	2) 2 chunked datasets with extensible array chunk indexing type (with/without data)
- *	3) 2 chunked datasets with version 2 B-tree chunk indexing type (with/without data)
- *	4) 2 chunked datasets with fixed array chunk indexing type (with/without data)
- *	5) 2 chunked datasets with implicit array chunk indexing type (with/without data)
+ *    1) 1 contiguous dataset (without data)
+ *    2) 2 chunked datasets with extensible array chunk indexing type (with/without data)
+ *    3) 2 chunked datasets with version 2 B-tree chunk indexing type (with/without data)
+ *    4) 2 chunked datasets with fixed array chunk indexing type (with/without data)
+ *    5) 2 chunked datasets with implicit array chunk indexing type (with/without data)
  * It will create the file with/without messages in the superblock extension depending
  * on the parameter "what".
  */
 static void
 gen_ext(const char *fname, unsigned new_format, unsigned what)
 {
-    hid_t	fid = -1;	 	/* file id */
-    hid_t	fapl = -1;	       	/* file access property list */
-    hid_t	fcpl = -1;	       	/* file creation property list */
-    hid_t	gid = -1;	       	/* group id */
-    hid_t   	sid = -1;       	/* space id */
-    hid_t	dcpl = -1;	    	/* dataset creation property id */
-    hid_t	did1 = -1, did2 = -1;	/* dataset id */
-    hsize_t 	dims1[1] = {10};     	/* dataset dimension */
-    hsize_t 	dims2[2] = {4, 6};     	/* dataset dimension */
-    hsize_t	max_dims[2];		/* maximum dataset dimension */
-    hsize_t 	c_dims[2] = {2, 3};    	/* chunk dimension */
-    int		i;		    	/* local index variable */
-    int     	buf[24];            	/* data buffer */
+    hid_t    fid = -1;         /* file id */
+    hid_t    fapl = -1;               /* file access property list */
+    hid_t    fcpl = -1;               /* file creation property list */
+    hid_t    gid = -1;               /* group id */
+    hid_t       sid = -1;           /* space id */
+    hid_t    dcpl = -1;            /* dataset creation property id */
+    hid_t    did1 = -1, did2 = -1;    /* dataset id */
+    hsize_t     dims1[1] = {10};         /* dataset dimension */
+    hsize_t     dims2[2] = {4, 6};         /* dataset dimension */
+    hsize_t    max_dims[2];        /* maximum dataset dimension */
+    hsize_t     c_dims[2] = {2, 3};        /* chunk dimension */
+    int        i;                /* local index variable */
+    int         buf[24];                /* data buffer */
 
     if((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
         goto error;
@@ -559,34 +562,34 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
 
     /* Generate messages that might be placed in superblock extension */
     switch(what) {
-	case 0:
-	    H5Pset_istore_k(fcpl, ISTORE_IK);
-	    break;
-	case 1:
-	    H5Pset_shared_mesg_nindexes(fcpl, 4);
-	    break;
-	case 2:
-	    H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_PAGE, FALSE, (hsize_t)1);
-	    break;
-	case 3:
-	    H5Pset_istore_k(fcpl, ISTORE_IK);
-	    H5Pset_shared_mesg_nindexes(fcpl, 4);
-	    break;
-	case 4:
-	    H5Pset_istore_k(fcpl, ISTORE_IK);
-	    H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, TRUE, (hsize_t)1);
-	    break;
-	case 5:
-	    H5Pset_shared_mesg_nindexes(fcpl, 4);
-	    H5Pset_file_space_page_size(fcpl, (hsize_t)512);
-	    break;
-	case 6:
-	    H5Pset_istore_k(fcpl, ISTORE_IK);
-	    H5Pset_shared_mesg_nindexes(fcpl, 4);
-	    H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_NONE, FALSE, (hsize_t)1);
-	    break;
-	default:
-	    break;
+    case 0:
+        H5Pset_istore_k(fcpl, ISTORE_IK);
+        break;
+    case 1:
+        H5Pset_shared_mesg_nindexes(fcpl, 4);
+        break;
+    case 2:
+        H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_PAGE, FALSE, (hsize_t)1);
+        break;
+    case 3:
+        H5Pset_istore_k(fcpl, ISTORE_IK);
+        H5Pset_shared_mesg_nindexes(fcpl, 4);
+        break;
+    case 4:
+        H5Pset_istore_k(fcpl, ISTORE_IK);
+        H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, TRUE, (hsize_t)1);
+        break;
+    case 5:
+        H5Pset_shared_mesg_nindexes(fcpl, 4);
+        H5Pset_file_space_page_size(fcpl, (hsize_t)512);
+        break;
+    case 6:
+        H5Pset_istore_k(fcpl, ISTORE_IK);
+        H5Pset_shared_mesg_nindexes(fcpl, 4);
+        H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_NONE, FALSE, (hsize_t)1);
+        break;
+    default:
+        break;
     }
 
     /* Create the file */
@@ -604,8 +607,8 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
         goto error;
 
 
-    /* 
-     * Create a contiguous dataset 
+    /*
+     * Create a contiguous dataset
      */
 
     /* Create dataspace */
@@ -622,8 +625,8 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
     if(H5Dclose(did1) < 0)
         goto error;
 
-    /* 
-     * Create 2 chunked datasets with extensible array chunk indexing type 
+    /*
+     * Create 2 chunked datasets with extensible array chunk indexing type
      * (one with data; one without data)
      */
 
@@ -657,8 +660,8 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
         goto error;
 
 
-    /* 
-     * Create 2 chunked datasets with version 2 B-tree chunk indexing type 
+    /*
+     * Create 2 chunked datasets with version 2 B-tree chunk indexing type
      * (one with data; one without data)
      */
 
@@ -689,7 +692,7 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
         goto error;
 
     /*
-     * Create 2 chunked datasets with fixed array chunk indexing type 
+     * Create 2 chunked datasets with fixed array chunk indexing type
      * (one with data; one without data)
      */
 
@@ -719,8 +722,8 @@ gen_ext(const char *fname, unsigned new_format, unsigned what)
         goto error;
 
 
-    /* 
-     * Create 2 chunked datasets with implicit chunk indexing type 
+    /*
+     * Create 2 chunked datasets with implicit chunk indexing type
      * (one with data; one without data)
      */
 
