@@ -316,6 +316,7 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
 #define HDpipe(F)               pipe(F)
 #define HDpow(X,Y)              pow(X,Y)
 /* printf() variable arguments */
+#define HDprintf(...)           HDfprintf(stdout, __VA_ARGS__)
 #define HDputc(C,F)             putc(C,F)
 #define HDputchar(C)            putchar(C)
 #define HDputs(S)               puts(S)
@@ -377,6 +378,7 @@ H5_DLL int c99_snprintf(char* str, size_t size, const char* format, ...);
 #define HDsnprintf              snprintf /*varargs*/
 #endif
 /* sprintf() variable arguments */
+#define HDsprintf    sprintf /*varargs*/
 #define HDsqrt(X)               sqrt(X)
 #ifdef H5_HAVE_RAND_R
 H5_DLL void HDsrand(unsigned int seed);
